@@ -323,6 +323,7 @@ void wgsim_core(const char *fn, int is_hap, uint64_t N, int dist, int std_dev, i
 					}			                                        \
 					else if (mut_type == NOCHANGE || mut_type == SUBSTITUTE) { \
 						char base = c & 0xf;                            \
+						int ob = nst_nt4_table[(int)ks->seq.s[i]];                   \
 						tmp_seq[x][k] = base;						    \
 						if (mut_type == SUBSTITUTE) {                   \
 							++n_sub[x];	                                \
@@ -331,12 +332,12 @@ void wgsim_core(const char *fn, int is_hap, uint64_t N, int dist, int std_dev, i
 						} else {                                        \
 							cigar[x] += 'M';		                    \
 							++end[x];}                                  \
-						if ((int)base == 1) {                           \
+						if ((int)base == 1 || ob == 1) {            \
 	                        c_bases[x][c_count[x]] = k;                 \
 							c_offset[x][c_count[x]] = offset[x];        \
 							++c_count[x];                               \
 							}                                           \
-						else if ((int)base == 2){                       \
+						else if ((int)base == 2 || ob == 2){        \
 	                        g_bases[x][g_count[x]] = k;                 \
 							g_offset[x][g_count[x]] = offset[x];        \
 							++g_count[x];                               \
@@ -377,7 +378,7 @@ void wgsim_core(const char *fn, int is_hap, uint64_t N, int dist, int std_dev, i
 			//for (k = 0; k < s[1]; ++k) tmp_seq[1][k] = tmp_seq[1][k] < 4? 3 - tmp_seq[1][k] : 4; // complement
 			if (ext_coor[0] < 0 || ext_coor[1] < 0) { // fail to generate the read(s)
 				--ii;
-				// should never need to delete, here for safety
+				// should never need to delete
 				delete c_bases[0];
 				delete c_bases[1];
 				delete c_bases;
